@@ -28,9 +28,11 @@ class DAO():
             c.execute(Utils.SQL_DROP_ACCOUNT_TABLE)
             c.execute(Utils.SQL_DROP_STATUS_TABLE)
             c.execute(Utils.SQL_DROP_USER_TABLE)
+            c.execute(Utils.SQL_DROP_SETTINGS_TABLE)
             c.execute(Utils.SQL_CREATE_ACCOUNT_TABLE)
             c.execute(Utils.SQL_CREATE_STATUS_TABLE)
             c.execute(Utils.SQL_CREATE_USER_TABLE)
+            c.execute(Utils.SQL_CREATE_SETTINGS_TABLE)
             con.commit()
             c.close()
             con.close()
@@ -378,14 +380,24 @@ class DAO():
         
 
     def save_settings(self,settings):
-        sql = """
-        UPDATE settings SET updatenum=:updatenum,downpic=:downpic
-        """
-        con = self.get_w_connection()
+        con = self.get_connection()
         c = con.cursor()
+        
+        c.execute("SELECT * FROM settings")
+        print c.rowcount
+        if c.rowcount == -1:
+            sql = """
+            INSERT INTO settings ("downpic", "updatenum")
+              VALUES (:downpic,:updatenum)
+            """
+        else:
+            sql = """
+            UPDATE settings SET updatenum=:updatenum,downpic=:downpic
+            """
+            
         c.execute(sql, settings)
+        
         con.commit()
-        self.logger.debug(c.rowcount)
         c.close()
         return settings
         
@@ -393,9 +405,12 @@ class DAO():
         sql = """
         SELECT * FROM settings limit 1
         """
-        con = self.get_w_connection()
+        con = self.get_connection()
         c = con.cursor()
+        
+        c.execute(Utils.SQL_CREATE_SETTINGS_TABLE)
         c.execute(sql)
+        
         r = c.fetchone()
         c.close()
         s=Utils.build_settings_from_row(r)
