@@ -152,6 +152,12 @@ class StatusModel(QAbstractListModel):
         if (role == Utils.ROLE_NAME):
             user=status["user"]
             return user["name"]
+        if (role == Utils.ROLE_SCREENNAME):
+            user=status["user"]
+            return user["screen_name"]
+        if (role == Utils.ROLE_ISVERIFIED):
+            user=status["user"]
+            return user["verified"]
         if (role == Utils.ROLE_TIME):
             createdAt=status["created_at"]
             time=Utils.gene_datetime_string(createdAt)
@@ -172,6 +178,7 @@ class StatusModel(QAbstractListModel):
         rt=None
         rtUser=None
         rtName=None
+        rtScreenName=None
         rtText=None
         rtThumbnailPic=None
         try:
@@ -186,6 +193,7 @@ class StatusModel(QAbstractListModel):
 	
             rtUser=rt["user"]
             rtName=rtUser["name"]
+            rtScreenName=rtUser["screen_name"]
             rtText=rt["text"]
             rtUserImage=Utils.AVATAR_DIR+str(status["account"])+"_"+str(rtUser["id"])
             if platform.os.access(rtUserImage, platform.os.W_OK) == 0:
@@ -198,6 +206,8 @@ class StatusModel(QAbstractListModel):
                     rtThumbnailPic=None
         if (role == Utils.ROLE_RT_NAME):
             return rtName
+        if (role == Utils.ROLE_RT_SCREENNAME):
+            return rtScreenName
         if (role == Utils.ROLE_RT_TEXT):
             return rtText
         if (role == Utils.ROLE_RT_AVATAR):
