@@ -3,8 +3,8 @@
 __author__= "Michael Wong"
 __modify__= "Binkcn"
 __email__="binkcn@vip.qq.com"
-__version__= "0.3.2"
-__build__="110928"
+__version__= "0.3.3"
+__build__="110930"
 
 import platform
 import sys
@@ -40,6 +40,7 @@ class DefaultCustomDelegate(QStyledItemDelegate):
         self.rightMargin=10
         self.textMargin=5
         self.avatarWidth=50
+        self.verifiedWidth=15
         self.nameHeight=20
         self.rtMargin=55
 
@@ -159,9 +160,10 @@ class DefaultCustomDelegate(QStyledItemDelegate):
 #            print "firstHeight", self.firstHeight
             rtHeight=0
             rtUser=index.data(Utils.ROLE_RT_NAME).toString()
+            rtScreenUser=index.data(Utils.ROLE_RT_SCREENNAME).toString()
             if rtUser!="":
                 #need to show the rt.
-                rtText="@"+rtUser+" : "+index.data(Utils.ROLE_RT_TEXT).toString()
+                rtText=rtUser+"(@"+rtScreenUser+") : "+index.data(Utils.ROLE_RT_TEXT).toString()
                 rtThumbnailFile=index.data(Utils.ROLE_RT_THUMBNAIL).toString()
                 rtHeight=self.cal_height_for_rt_status(option,rtText,rtThumbnailFile)
 
@@ -299,21 +301,34 @@ class DefaultCustomDelegate(QStyledItemDelegate):
 
 #        model = index.model()
         text = index.data(Qt.DisplayRole).toString()
-        screenname=index.data(Utils.ROLE_NAME).toString()
+        name=index.data(Utils.ROLE_NAME).toString()
+        screenname=index.data(Utils.ROLE_SCREENNAME).toString()
         userImage=index.data(Utils.ROLE_AVATAR).toString()
         time=index.data(Utils.ROLE_TIME).toString()
+        isverified=index.data(Utils.ROLE_ISVERIFIED).toString()
 
         # Draw avatar
         avatar=QPixmap(userImage)
         painter.drawPixmap(x1 + self.leftMargin, y1 + self.topMargin, self.avatarWidth, self.avatarWidth, avatar)
 
-        # Draw screenname
+        # Draw verified
+        verifiedLeft = 0
+        if str(isverified)=="1":
+            verifiedLeft = 20
+            verified = Utils.VERIFIED_FILE
+            verified=QPixmap(verified)
+            verifiedx = x1 + 55
+            verifiedy = y1 + 5
+            painter.drawPixmap(verifiedx + self.leftMargin, verifiedy + self.topMargin, self.verifiedWidth, self.verifiedWidth, verified)
+
+        # Draw name
+        name = name+"(@"+screenname+")"
         painter.setFont(self.miniFont)
         painter.setPen(self.user_color)
-        painter.drawText(option.rect.adjusted(self.leftMargin+self.avatarWidth+self.textMargin, self.topMargin, -self.rightMargin, -self.bottomMargin),
+        painter.drawText(option.rect.adjusted(verifiedLeft + self.leftMargin+self.avatarWidth+self.textMargin, self.topMargin, -self.rightMargin, -self.bottomMargin),
                          int(Qt.AlignTop) | int(Qt.AlignLeft),
-                         screenname)
-
+                         name)
+        
         # Draw Timeline
 #        painter.setFont(self.miniFont)
         painter.setPen(self.time_color)
@@ -321,9 +336,6 @@ class DefaultCustomDelegate(QStyledItemDelegate):
                          int(Qt.AlignTop) | int(Qt.AlignRight),
                          time)
 
-
-
-
         # Draw tweet
         painter.setPen(self.text_color)
         painter.setFont(self.normFont)
@@ -351,9 +363,10 @@ class DefaultCustomDelegate(QStyledItemDelegate):
 #        print new_rect.height()
 #        print self.firstHeight
         rtUser=index.data(Utils.ROLE_RT_NAME).toString()
+        rtScreenUser=index.data(Utils.ROLE_RT_SCREENNAME).toString()
         if rtUser!="":
             #need to draw the rt.
-            rtText="@"+rtUser+" : "+index.data(Utils.ROLE_RT_TEXT).toString()
+            rtText=rtUser+"(@"+rtScreenUser+") : "+index.data(Utils.ROLE_RT_TEXT).toString()
             rtAvatar=QPixmap(index.data(Utils.ROLE_RT_AVATAR).toString())
 
             #draw a line
@@ -699,6 +712,7 @@ class UserButton(QPushButton):
         self.rightMargin=10
         self.textMargin=10
         self.avatarWidth=50
+        self.verifiedWidth=15
 
         self.fm = None
         self.minifm = None
@@ -731,16 +745,27 @@ class UserButton(QPushButton):
             if platform.os.access(userImage, platform.os.W_OK) == 0:
                 userImage=Utils.DEFAULT_AVATAR_FILE
             text=user["name"]+"(@"+user["screen_name"]+")"
-            if user["verified"]==1:
-                text=text+" [认证用户]"
+#            if user["verified"]==1:
+#                text=text+" [认证用户]"
             text=text+"\n"
             text=text+"来自："+user["location"]+" 听众:"+str(user["followers_count"])+" 收听:"+str(user["friends_count"])+" 广播:"+str(user["statuses_count"])+""
 
+        # Draw verified
+        verifiedLeft = 0
+        if user["verified"]==1:
+            verifiedLeft = 20
+            verified = Utils.VERIFIED_FILE
+            verified=QPixmap(verified)
+            verifiedx = x1 + 55
+            verifiedy = y1 + 0
+            painter.drawPixmap(verifiedx + self.leftMargin, verifiedy + self.topMargin, self.verifiedWidth, self.verifiedWidth, verified)
+
+
         avatar=QPixmap(userImage)
         painter.drawPixmap(x1 + self.leftMargin, y1 + self.topMargin, self.avatarWidth, self.avatarWidth, avatar)
         painter.save()
         painter.setFont(self.miniFont)
-        painter.drawText(event.rect().adjusted(self.leftMargin+self.avatarWidth+self.textMargin, 5, 0, 0),
+        painter.drawText(event.rect().adjusted(verifiedLeft + self.leftMargin+self.avatarWidth+self.textMargin, 5, 0, 0),
                          int(Qt.AlignTop) | int(Qt.AlignLeft),
                          text)
 
@@ -990,13 +1015,13 @@ class NewStatusWindow(QMainWindow):
                     userImage=Utils.DEFAULT_AVATAR_FILE
                 self.avatarLabel.setPixmap(QPixmap(userImage))
 
-                self.statusLabel.setText(user["name"]+" : "+status["text"])
+                self.statusLabel.setText(user["name"]+"(@"+user["screen_name"]+") : "+status["text"])
                 self.statusLabel.show()
             elif timelineType==Utils.TIMELINE_TYPE_DM:
                 #dm
                 self.textEdit.setFixedSize(760,150)
                 self.statusFrame.hide()
-                text="对@"+status["user"]["name"]+" 说:"
+                text="对 @"+status["user"]["name"]+" 说:"
                 self.textEdit.setText(text)
         self.move_to_end()
 
@@ -1212,7 +1237,22 @@ class StatusContentView(QWebView):
             </tr>
             <tr>
                 <td width="100%" align="center">
-                    $rtPic
+                    <span id="rttip"></span><br /><br />
+                    <img id="rtobjpic" src="$rtspic" onclick="javascript:doLoadRtImage();" />
+                    <span style="display:none;" id="rtpicurl">$rtpic</span>
+                    <script type="text/javascript">
+                        function doLoadRtImage(){
+                            document.getElementById('rtobjpic').src = document.getElementById('rtpicurl').innerHTML;
+                            document.getElementById('rttip').innerHTML = 'Downloading...';
+                        }
+                        
+                        doInitRt();
+                        function doInitRt(){
+                            if (document.getElementById('rtobjpic').src.length > 5){
+                                document.getElementById('rttip').innerHTML = 'Double-click this image to download large image.';
+                            }
+                        }
+                    </script>
                 </td>
             </tr>
         """
@@ -1245,26 +1285,50 @@ class StatusContentView(QWebView):
         rtUser=""
         rtName=""
         rtText=""
-        rtPic=""
+        rtpic=""
+        rtspic=""
         rtAvatar=""
         rt=status["retweeted_status"]
         if rt!=None:
             html=string.replace(html, "$rt", rtHtml)
             rtUser=rt["user"]
             rtName=rtUser["name"]
-#            rtUserImage=Utils.AVATAR_DIR+str(status["account"])+"_"+str(rtUser["id"])
-#            if platform.os.access(rtUserImage, platform.os.W_OK) == 0:
-#                rtUserImage=Utils.AVATAR_DIR+"default.jpg"
-#            rtAvatar="<img src=\"file:///"+rtUserImage+"\"/>"
-            rtUserImage=rtUser["profile_image_url"]
-            rtAvatar="<img src=\""+rtUserImage+"\"/>"
+            rtScreenName=rtUser["screen_name"]
+            rtUserImage=Utils.AVATAR_DIR+str(status["account"])+"_"+str(rtUser["id"])
+            if platform.os.access(rtUserImage, platform.os.W_OK) == 0:
+                rtUserImage=Utils.DEFAULT_AVATAR_FILE
+            rtAvatar="<img src=\"file:///"+rtUserImage+"\"/>"
 
+#            rtUserImage=rtUser["profile_image_url"]
+#            if rtUserImage==None:
+#                rtUserImage=Utils.AVATAR_DIR+"default.jpg"
+#            rtAvatar="<img src=\""+rtUserImage+"\"/>"
+            
             rtText=rt["text"]
-            rtPic=rt["original_pic"]
-            if rtPic==None:
-                rtPic=""
+            rtspic=rt["thumbnail_pic"]
+            rtpic=rt["original_pic"]
+            if rtpic==None:
+                rtpic=""
+            
+            if rtspic!=None:
+                filename=rtspic.split("/")[-1]
+                if len(filename)==0 or filename=="460":
+                    filename=rtspic.split("/")[-2]
+                
+                rtspic=Utils.THUMBNAIL_DIR+str(rt["account"])+"_"+str(rt["id"])+"_"+filename
+                if os.access(rtspic, platform.os.W_OK) == 0:
+                    rtspic=""
+                else:
+                    rtspic = "file:///" + rtspic
             else:
-                rtPic="<img src=\""+rtPic+"\"/>"
+                rtspic=""
+            
+#            rtPic=rt["original_pic"]
+#            if rtPic==None:
+#                rtPic=""
+#            else:
+#                rtPic="<img src=\""+rtPic+"\"/>"
+
         else:
             html=string.replace(html, "$rt", "")
 
@@ -1276,10 +1340,11 @@ class StatusContentView(QWebView):
         html=string.replace(html, "$pic", pic)
         if rt!=None:
             rtText = self.parseURL(rtText, status["bmiddle_pic"])
-            html=string.replace(html, "$rtText", "@"+rtName+" : "+rtText)
+            html=string.replace(html, "$rtText", rtName+"@("+rtScreenName+") : "+rtText)
         else:
             html=string.replace(html, "$rtText", "")
-        html=string.replace(html, "$rtPic", rtPic)
+        html=string.replace(html, "$rtspic", rtspic)
+        html=string.replace(html, "$rtpic", rtpic)
         html=string.replace(html, "$rtAvatar", rtAvatar)
         html=self.repFace(html, status["bmiddle_pic"])
         #print html
